# apiget

Automation of API fetching and converting to JSON

## Importing
```python
from apiget import API
```

## Recommended usage

Use the API class in this simple manner:

```python
useful_data_json = API(api_url)()
```

It's that simple

version : 0.0.2

Status: Almost done

author: Al Razi

pypi link: https://pypi.org/project/apiget/0.0.1/

Facebook/Messenger: https://www.facebook.com/abartoha